@@ -7,7 +7,8 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-spell-fu
 ;; Keywords: convenience
-;; Version: 0.3
+;; Package-Version: 20250913.2251
+;; Package-Revision: b141e2e24e3d
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -15,7 +16,7 @@
 ;; This package checks the spelling of on-screen text.
 ;;
 
-;;; Usage:
+;;; Usage
 
 ;;
 ;; Write the following code to your .emacs file:
@@ -45,7 +46,7 @@
 
 ;; For `face-list-p'.
 (require 'faces)
-;; For variables such as `ispell-personal-dictionary', local dictionary, etc.
+;; For variables we read `ispell-personal-dictionary' local dictionary, etc.
 (require 'ispell)
 ;; For `string-blank-p'.
 (require 'subr-x)
@@ -77,7 +78,7 @@
 
 (defcustom spell-fu-directory (locate-user-emacs-file "spell-fu" ".emacs-spell-fu")
   "The directory to store dictionary data."
-  :type 'directory)
+  :type 'string)
 
 (defcustom spell-fu-idle-delay 0.25
   "Idle time to wait before highlighting.
@@ -91,7 +92,7 @@ Set to 0.0 to highlight immediately (as part of syntax highlighting)."
 (defcustom spell-fu-word-delimit-camel-case nil
   "Support camel-case for delimiting word boundaries.
 
-So `HelloWorld' would be checked as two words instead of one.
+So `HelloWorld' would be checked a two words instead of one.
 This is performed as an additional check for words that would
 otherwise be marked as incorrect."
   :type 'boolean)
@@ -101,9 +102,9 @@ otherwise be marked as incorrect."
   :type 'boolean)
 
 (defvar-local spell-fu-buffer-session-localwords nil
-  "Optional buffer-local word list.
+  "Optional buffer-local word-list of words.
 This is intended to be set by file-locals or dir-locals.
-Call `spell-fu-buffer-session-localwords-update' after run-time modifications.")
+Call `spell-fu-buffer-session-localwords-refresh' after run-time modifications.")
 
 ;;;###autoload
 (put 'spell-fu-buffer-session-localwords 'safe-local-variable #'spell-fu-list-of-strings-p)
@@ -136,8 +137,7 @@ use `spell-fu-dictionary-add'.")
 (defface spell-fu-incorrect-face
   '((((supports :underline (:style wave))) :underline (:style wave :color "red"))
     (t :underline t :inherit error))
-  "Face for incorrect spelling."
-  :group 'spell-fu)
+  "Face for incorrect spelling.")
 
 ;; See '-' as a word boundary \b, so 'full-screen' is detected as two words.
 (defvar-local spell-fu-syntax-table
@@ -179,8 +179,8 @@ over which words are being checked.
 
 Notes:
 
-- The ranges passed in are guaranteed to be on line boundaries.
-- Call `spell-fu-check-word' on each word.
+- The ranges passed in a guaranteed to be on line boundaries.
+- Calling `spell-fu-check-word' on each word.
 
 - You may explicitly mark a range as incorrect using
   `spell-fu-mark-incorrect' which takes the range to mark as arguments.")
@@ -197,7 +197,7 @@ Notes:
 ;; Always check this has not been deleted (has a valid buffer) before use.
 (defvar-local spell-fu--idle-overlay-last nil)
 
-;; Cache the result of: `(mapcar #'symbol-value spell-fu-dictionaries)'
+;; Cache the result of: `(mapcar (lambda (dict) (symbol-value dict)) spell-fu-dictionaries)'
 (defvar-local spell-fu--cache-table-list nil)
 
 ;; The buffer local dictionary generated from `spell-fu-buffer-session-localwords'.
@@ -221,14 +221,16 @@ Notes:
 
 (defmacro spell-fu--debug-message (fmt &rest args)
   "Debug message logging passing FMT and ARGS to `message'."
-  `(when spell-fu-debug
-     (message (concat "spell-fu-debug: " ,fmt) ,@args)))
+  ;; When emacs 28.2 support is dropped,
+  ;; this can simply check `spell-fu-debug', see: #36.
+  (when (bound-and-true-p spell-fu-debug)
+    `(apply #'message (list (concat "spell-fu-debug: " ,fmt) ,@args))))
 
 ;; ---------------------------------------------------------------------------
 ;; Dictionary Utility Functions
 
 (defsubst spell-fu--canonicalize-word-downcase (word)
-  "Return UTF-8 encoded WORD (must already be lowercase)."
+  "Return lowercase UTF-8 encoded WORD (must already be `downcase')."
   (encode-coding-string word 'utf-8))
 
 (defsubst spell-fu--canonicalize-word (word)
@@ -278,7 +280,7 @@ Notes:
                                (hash-table-size (symbol-value dict))))))
 
 (defun spell-fu--dictionaries-test-any (test-fn)
-  "Return non-nil if any dictionaries match TEST-FN."
+  "Remove any dictionaries that match TEST-FN."
   (declare (important-return-value t))
   (let ((result nil))
     (let ((dict-list spell-fu-dictionaries))
@@ -290,7 +292,7 @@ Notes:
     result))
 
 (defun spell-fu--dictionaries-remove-any (test-fn)
-  "Remove any dictionaries that match TEST-FN."
+  "Return non-nil if any dictionaries match TEST-FN."
   (declare (important-return-value nil))
   (setq spell-fu-dictionaries
         (remq
@@ -299,25 +301,26 @@ Notes:
           (lambda (dict)
             (cond
              ((funcall test-fn dict)
-              nil)
+              dict)
              (t
-              dict)))
+              nil)))
           spell-fu-dictionaries))))
 
 (defun spell-fu--cache-file (dict)
-  "Return the location of the cache file for dictionary DICT."
+  "Return the location of the cache file with dictionary DICT."
   (declare (important-return-value t))
   (expand-file-name (format "words_%s.el.data" (symbol-name dict)) spell-fu-directory))
 
 (defun spell-fu--words-file (dict)
-  "Return the location of the word-list for dictionary DICT."
+  "Return the location of the word-list with dictionary DICT."
   (declare (important-return-value t))
   (expand-file-name (format "words_%s.txt" (symbol-name dict)) spell-fu-directory))
 
 (defun spell-fu--refresh-cache-table-list ()
   "Refresh internal list `spell-fu--cache-table-list'."
   (declare (important-return-value nil))
-  (setq spell-fu--cache-table-list (mapcar #'symbol-value spell-fu-dictionaries)))
+  (setq spell-fu--cache-table-list
+        (mapcar (lambda (dict) (symbol-value dict)) spell-fu-dictionaries)))
 
 (defun spell-fu--refresh ()
   "Reset spell-checked overlays in the current buffer."
@@ -339,9 +342,9 @@ Notes:
         (spell-fu--refresh)))))
 
 (defun spell-fu--get-edit-candidate-dictionaries (word action)
-  "Return dictionaries for which it makes sense to perform ACTION on WORD.
+  "Return dictionaries for which it make sense to perform ACTION on WORD.
 
-ACTION is `remove' or `add'.  Returned candidates are dictionaries
+ACTION is `'remove' or `'add'.  Returned candidates are dictionaries
 which support the operation, and correspondingly do / do not
 already contain WORD."
   (declare (important-return-value t))
@@ -368,7 +371,7 @@ already contain WORD."
 
 (defun spell-fu--read-dictionary (candidate-dicts prompt)
   "Ask the user to select one dictionary from CANDIDATE-DICTS.
-PROMPT is shown to the user in completing-read."
+PROMPT is shown to the users completing read."
   (declare (important-return-value t))
   (cond
    ((<= (length candidate-dicts) 1)
@@ -389,7 +392,7 @@ PROMPT is shown to the user in completing-read."
 (defmacro spell-fu--with-advice (advice &rest body)
   "Execute BODY with ADVICE temporarily enabled.
 
-Each advice is a triplet of (SYMBOL HOW FUNCTION),
+Advice are triplets of (SYMBOL HOW FUNCTION),
 see `advice-add' documentation."
   (declare (indent 1))
   (let ((advice-list advice)
@@ -449,9 +452,10 @@ Optional argument BODY runs with the depth override."
      ,@body))
 
 (defmacro spell-fu--setq-expand-range-to-line-boundaries (pos-beg pos-end)
-  "Set POS-BEG to the line beginning, POS-END to the line end."
-  `(let ((inhibit-field-text-motion t))
-     (save-excursion
+  "Set POS-BEG the the line beginning, POS-END to the line end."
+  ;; Ignore field boundaries.
+  (let ((inhibit-field-text-motion t))
+    `(save-excursion
        ;; Extend the ranges to line start/end.
        (goto-char ,pos-end)
        (setq ,pos-end (pos-eol))
@@ -464,14 +468,14 @@ Optional argument BODY runs with the depth override."
   (with-current-buffer buffer
     (save-excursion
       (goto-char (point-min))
-      (while (null (eobp))
+      (while (not (eobp))
         (push (buffer-substring-no-properties (pos-bol) (pos-eol)) lines)
         (forward-line 1))))
   lines)
 
 (defun spell-fu--removed-changed-overlay (overlay after _beg _end &optional _len)
   "Hook for removing OVERLAY which is being edited.
-Argument AFTER when non-nil, the overlay is not deleted."
+Argument AFTER, ignore when true."
   (declare (important-return-value nil))
   (unless after
     (delete-overlay overlay)))
@@ -500,15 +504,15 @@ Argument AFTER when non-nil, the overlay is not deleted."
     nil)))
 
 (defun spell-fu--faces-at-point (pos)
-  "Return the named faces that the `read-face-name' or `face' property use.
-Argument POS is the position to check."
+  "Add the named faces that the `read-face-name' or `face' property use.
+Argument POS return faces at this point."
   (declare (important-return-value t))
   ;; NOTE: use `get-text-property' instead of `get-char-property' so overlays are excluded,
   ;; since this causes overlays with `hl-line-mode' (for example) to mask other faces.
   ;; If we want to include faces of overlays, this could be supported.
   (let ((faceprop (or (get-text-property pos 'read-face-name) (get-text-property pos 'face))))
     (when faceprop
-      ;; List of faces to return.
+      ; List of faces to return.
       (spell-fu--faces-as-normalized-list faceprop))))
 
 (defun spell-fu--next-faces-prop-change (pos limit)
@@ -539,7 +543,7 @@ Argument POS is the position to check."
 (defun spell-fu-list-of-strings-p (obj)
   "Return t when OBJ is a list of strings."
   (declare (important-return-value t))
-  (and (listp obj) (null (memq nil (mapcar #'stringp obj)))))
+  (and (listp obj) (not (memq nil (mapcar #'stringp obj)))))
 
 ;; ---------------------------------------------------------------------------
 ;; Word List Cache
@@ -549,27 +553,27 @@ Argument POS is the position to check."
 
 The resulting cache is returned as a minor optimization for first-time loading,
 where we need to create this data in order to write it,
-saving some time by not reading it back."
+save some time by not spending time reading it back."
   (declare (important-return-value t))
   (message "%S" (file-name-nondirectory cache-file))
   (let ((cache-header
          ;; The header, an associative list of items.
          (list (cons "version" spell-fu--cache-version)))
         (word-table nil)
-        ;; Needed on Windows to prevent CRLF line endings in strings.
+        ;; Needed for Windows to prevent CRLF including new-lines in strings.
         (coding-system-for-read 'utf-8-unix)
         (coding-system-for-write 'utf-8-unix))
 
     (with-temp-buffer
       (insert-file-contents-literally words-file)
       (setq word-table (make-hash-table :test #'equal :size (count-lines (point-min) (point-max))))
-      (while (null (eobp))
+      (while (not (eobp))
         (let ((l (buffer-substring-no-properties (pos-bol) (pos-eol))))
-          ;; Value of 't' is just for simplicity, it's not used except to check the item exists.
+          ;; Value of 't' is just for simplicity, it's no used except for check the item exists.
           (puthash (spell-fu--canonicalize-word l) t word-table)
           (forward-line 1))))
 
-    ;; Write it to a file.
+    ;; Write write it to a file.
     (with-temp-buffer
       (prin1 cache-header (current-buffer))
       (prin1 word-table (current-buffer))
@@ -586,8 +590,9 @@ saving some time by not reading it back."
         (spell-fu--cache-from-word-list-impl words-file cache-file)
       (error
        ;; Should be rare: if the file is corrupt or cannot be read for any reason.
-       (message "failed, %s" (error-message-string err))
-       nil))))
+       (progn
+         (message "failed, %s" (error-message-string err))
+         nil)))))
 
 (defun spell-fu--cache-words-load-impl (cache-file)
   "Return the Lisp content from reading CACHE-FILE.
@@ -622,8 +627,9 @@ the caller will need to regenerate the cache."
         (spell-fu--cache-words-load-impl cache-file)
       (error
        ;; Should be rare: if the file is corrupt or cannot be read for any reason.
-       (message "failed, %s" (error-message-string err))
-       nil))))
+       (progn
+         (message "failed, %s" (error-message-string err))
+         nil)))))
 
 
 ;; ---------------------------------------------------------------------------
@@ -640,12 +646,12 @@ Arguments WORD-LOCASE & WORD-UPCASE are simply to avoid extra computation."
          (i word-length)
          ;; Build list in reverse so it's ordered from first to last.
          (result nil))
-    (while (null (zerop i))
+    (while (not (zerop i))
       (decf i)
       (let* ((ch-nat (aref word i))
              (ch-locase (aref word-locase i))
              (ch-upcase (aref word-upcase i))
-             (is-caps (null (eq ch-nat ch-locase))))
+             (is-caps (not (eq ch-nat ch-locase))))
 
         (cond
          ;; Ignore punctuation (typically apostrophe).
@@ -657,11 +663,11 @@ Arguments WORD-LOCASE & WORD-UPCASE are simply to avoid extra computation."
           (cond
            (was-ignore
             (setq was-ignore nil))
-           ((and is-caps (null was-caps))
+           ((and is-caps (not was-caps))
             (when (< i i-prev)
               (push (cons i i-prev) result)
               (setq i-prev i)))
-           ((and was-caps (null is-caps))
+           ((and was-caps (not is-caps))
             (let ((i-ofs (1+ i)))
               (when (< i-ofs i-prev)
                 (push (cons i-ofs i-prev) result)
@@ -679,7 +685,7 @@ Uses WORD, WORD-LOCASE & WORD-UPCASE to calculate delimiting."
    ;; The option to delimit by camel-case isn't enabled, early exit.
    ((null spell-fu-word-delimit-camel-case)
     nil)
-   ;; Early exit common case where only the first letter is capitalized.
+   ;; Early exit common case Where only the first letter is capitalized.
    ((string-equal (substring word 1) (substring word-locase 1))
     nil)
    (t
@@ -707,9 +713,9 @@ Otherwise remove all overlays."
   (let ((item-ov (make-overlay pos-beg pos-end)))
     (overlay-put item-ov 'spell-fu-mode t)
     (overlay-put item-ov 'face 'spell-fu-incorrect-face)
-    (overlay-put item-ov 'modification-hooks '(spell-fu--removed-changed-overlay))
-    (overlay-put item-ov 'insert-in-front-hooks '(spell-fu--removed-changed-overlay))
-    (overlay-put item-ov 'insert-behind-hooks '(spell-fu--removed-changed-overlay))
+    (overlay-put item-ov 'modification-hooks 'spell-fu--removed-changed-overlay)
+    (overlay-put item-ov 'insert-in-front-hooks 'spell-fu--removed-changed-overlay)
+    (overlay-put item-ov 'insert-behind-hooks 'spell-fu--removed-changed-overlay)
     (overlay-put item-ov 'evaporate t)
     item-ov))
 
@@ -784,10 +790,10 @@ Argument POS-END the end position of WORD."
 ;; ---------------------------------------------------------------------------
 ;; Range Checking Commands
 ;;
-;; These functions are valid values for the `spell-fu-check-range' buffer local variable.
+;; These functions are value values for the `spell-fu-check-range' buffer local variable.
 ;;
-;; Note that the callers of these functions extend the range to line delimiters,
-;; to ensure there is no chance of the points being in the middle of a word.
+;; Note that the callers of these function extends the range to line delimiters,
+;; to ensure there no chance of the points being in the middle of a word.
 ;;
 
 (defun spell-fu--check-faces-at-point (pos)
@@ -820,7 +826,8 @@ This only checks the text matching face rules."
             ;; In practice this is likely caused by escape characters, e.g.
             ;; "test\nthe text" where "\n" may have separate highlighting.
             (while (< pos-beg pos-end)
-              (let* ((point-end-iter (spell-fu--next-faces-prop-change pos-beg pos-end))
+              (let* ((point-end-iter ; Set to `ok-beg' next iteration to avoid duplicate checks.
+                      (spell-fu--next-faces-prop-change pos-beg pos-end))
                      (ok-end-iter
                       (and (< point-end-iter pos-end)
                            (spell-fu--check-faces-at-point point-end-iter))))
@@ -872,7 +879,7 @@ This only checks the text matching face rules."
             (spell-fu-check-word word-beg word-end (match-string-no-properties 0))))))))
 
 (defun spell-fu-check-range-default (pos-beg pos-end)
-  "Check spelling for POS-BEG & POS-END, checking comments and strings."
+  "Check spelling POS-BEG & POS-END, checking comments and strings."
   (declare (important-return-value nil))
   (cond
    ((or spell-fu-faces-include spell-fu-faces-exclude)
@@ -885,7 +892,7 @@ This only checks the text matching face rules."
 ;; Immediate Style (spell-fu-idle-delay zero or lower)
 
 (defun spell-fu--font-lock-fontify-region (pos-beg pos-end)
-  "Update spelling for POS-BEG & POS-END, checking all text."
+  "Update spelling for POS-BEG & POS-END to the queue, checking all text."
   (declare (important-return-value nil))
   (spell-fu--setq-expand-range-to-line-boundaries
    ;; Warning these values are set in place.
@@ -897,7 +904,7 @@ This only checks the text matching face rules."
   (declare (important-return-value nil))
 
   ;; It's important this is added with a depth of 100,
-  ;; because we want the font faces (comments, strings, etc.) to be set so
+  ;; because we want the font faces (comments, string etc) to be set so
   ;; the spell checker can read these values which may include/exclude words.
   (spell-fu--with-add-hook-depth-override 100
     (jit-lock-register #'spell-fu--font-lock-fontify-region)))
@@ -948,11 +955,12 @@ when checking the entire buffer for example."
                         (funcall spell-fu-check-range pos-beg pos-end)
                         t)
                     (error
-                     ;; Keep since this should be very rare.
-                     (message "Early exit 'spell-fu-mode': %s" (error-message-string err))
-                     ;; Break out of the loop.
-                     (setq overlays-in-view nil)
-                     nil))
+                     (progn
+                       ;; Keep since this should be very rare.
+                       (message "Early exit 'spell-fu-mode': %s" (error-message-string err))
+                       ;; Break out of the loop.
+                       (setq overlays-in-view nil)
+                       nil)))
 
               ;; Don't delete the overlay since it may extend outside the window bounds,
               ;; always delete the range instead.
@@ -971,7 +979,7 @@ when checking the entire buffer for example."
 (defun spell-fu--idle-font-lock-region-pending (pos-beg pos-end)
   "Track the range to spell check, adding POS-BEG & POS-END to the queue."
   (declare (important-return-value nil))
-  (when (and spell-fu--idle-overlay-last (null (overlay-buffer spell-fu--idle-overlay-last)))
+  (when (and spell-fu--idle-overlay-last (not (overlay-buffer spell-fu--idle-overlay-last)))
     (setq spell-fu--idle-overlay-last nil))
 
   (unless (and spell-fu--idle-overlay-last
@@ -991,7 +999,7 @@ when checking the entire buffer for example."
       ;; Handy for debugging pending regions to be checked.
       ;; (overlay-put item-ov 'face '(:background "#000000" :extend t))
       (overlay-put item-ov 'spell-fu-pending t)
-      (overlay-put item-ov 'evaporate t)
+      (overlay-put item-ov 'evaporate 't)
       (setq spell-fu--idle-overlay-last item-ov)))
 
   ;; Use `inhibit-quit' as a way to check if `jit-lock-stealth' is in use.
@@ -1006,11 +1014,11 @@ when checking the entire buffer for example."
 ;;
 ;; - The timer is kept active as long as the local mode is enabled.
 ;; - Entering a buffer runs the buffer local `window-state-change-hook'
-;;   immediately, which checks if the mode is enabled,
-;;   setting up the global timer if it is.
-;; - Switching to any other buffer won't run this hook;
-;;   we rely on the idle timer itself running, which detects the active mode,
-;;   canceling itself if the mode isn't active.
+;;   immediately which checks if the mode is enabled,
+;;   set up the global timer if it is.
+;; - Switching any other buffer wont run this hook,
+;;   rely on the idle timer it's self running, which detects the active mode,
+;;   canceling it's self if the mode isn't active.
 ;;
 ;; This is a reliable way of using a global,
 ;; repeating idle timer that is effectively buffer local.
@@ -1020,11 +1028,11 @@ when checking the entire buffer for example."
 (defvar spell-fu--global-timer nil)
 ;; When t, the timer will update buffers in all other visible windows.
 (defvar spell-fu--dirty-flush-all nil)
-;; When non-nil, the buffer should be updated when inactive.
+;; When true, the buffer should be updated when inactive.
 (defvar-local spell-fu--dirty nil)
 
 (defun spell-fu--time-callback-or-disable ()
-  "Callback that runs the repeat timer."
+  "Callback that run the repeat timer."
   (declare (important-return-value nil))
 
   ;; Ensure all other buffers are highlighted on request.
@@ -1079,7 +1087,7 @@ when checking the entire buffer for example."
       (setq spell-fu--global-timer nil)))))
 
 (defun spell-fu--time-reset ()
-  "Run when the buffer changes."
+  "Run this when the buffer was changed."
   (declare (important-return-value nil))
   ;; Ensure changing windows doesn't leave other buffers with stale highlight.
   (cond
@@ -1091,7 +1099,7 @@ when checking the entire buffer for example."
     (spell-fu--time-ensure nil))))
 
 (defun spell-fu--time-buffer-local-enable ()
-  "Ensure buffer-local state is enabled."
+  "Ensure buffer local state is enabled."
   (declare (important-return-value nil))
   ;; Needed in case focus changes before the idle timer runs.
   (setq spell-fu--dirty-flush-all t)
@@ -1100,7 +1108,7 @@ when checking the entire buffer for example."
   (add-hook 'window-state-change-hook #'spell-fu--time-reset nil t))
 
 (defun spell-fu--time-buffer-local-disable ()
-  "Ensure buffer-local state is disabled."
+  "Ensure buffer local state is disabled."
   (declare (important-return-value nil))
   (kill-local-variable 'spell-fu--dirty)
   (spell-fu--time-ensure nil)
@@ -1184,7 +1192,7 @@ Return t when found, otherwise nil."
         (point-prev nil)
         (point-found nil))
     (save-excursion
-      (while (and (null point-found) (null (equal (point) point-prev)))
+      (while (and (null point-found) (not (equal (point) point-prev)))
         (let ((pos-beg (pos-bol))
               (pos-end (pos-eol)))
 
@@ -1238,53 +1246,47 @@ Return t when found, otherwise nil."
   (interactive)
   (spell-fu--goto-next-or-previous-error -1))
 
-(defun spell-fu-word-add (dict &optional word)
+(defun spell-fu-word-add (dict)
   "Add the current word to the dictionary DICT.
 
-Return t when the word has been added.
-WORD defaults to the word at point if not provided."
+Return t when the word has been added."
   (declare (important-return-value nil))
-  (interactive (let ((w (spell-fu--word-at-point)))
-                 (list
-                  (spell-fu--read-dictionary
-                   (spell-fu--get-edit-candidate-dictionaries w 'add) "Add to dictionary: ")
-                  w)))
-  (unless word
-    (setq word (spell-fu--word-at-point)))
-  (cond
-   (dict
-    (let ((encoded-word (spell-fu--canonicalize-word word)))
-      (funcall (get dict 'add-word) encoded-word)
-      (puthash encoded-word t (symbol-value dict))
-      t))
-   (t
-    (message "Cannot add %S to any active dictionary." word)
-    nil)))
+  (interactive (list
+                (spell-fu--read-dictionary
+                 (spell-fu--get-edit-candidate-dictionaries
+                  (spell-fu--word-at-point) 'add)
+                 "Add to dictionary: ")))
+  (let ((word (spell-fu--word-at-point)))
+    (cond
+     (dict
+      (let ((encoded-word (spell-fu--canonicalize-word word)))
+        (funcall (get dict 'add-word) encoded-word)
+        (puthash encoded-word t (symbol-value dict))
+        t))
+     (t
+      (message "Cannot add %S to any active dictionary." word)
+      nil))))
 
-(defun spell-fu-word-remove (dict &optional word)
+(defun spell-fu-word-remove (dict)
   "Remove the current word from the dictionary DICT.
 
-Return t when the word has been removed.
-WORD defaults to the word at point if not provided."
+Return t when the word has been removed."
   (declare (important-return-value nil))
-  (interactive (let ((w (spell-fu--word-at-point)))
-                 (list
-                  (spell-fu--read-dictionary
-                   (spell-fu--get-edit-candidate-dictionaries
-                    w 'remove)
-                   "Remove from dictionary: ")
-                  w)))
-  (unless word
-    (setq word (spell-fu--word-at-point)))
-  (cond
-   (dict
-    (let ((encoded-word (spell-fu--canonicalize-word word)))
-      (funcall (get dict 'remove-word) encoded-word)
-      (remhash encoded-word (symbol-value dict))
-      t))
-   (t
-    (message "Cannot remove %S from any active dictionary." word)
-    nil)))
+  (interactive (list
+                (spell-fu--read-dictionary
+                 (spell-fu--get-edit-candidate-dictionaries
+                  (spell-fu--word-at-point) 'remove)
+                 "Remove from dictionary: ")))
+  (let ((word (spell-fu--word-at-point)))
+    (cond
+     (dict
+      (let ((encoded-word (spell-fu--canonicalize-word word)))
+        (funcall (get dict 'remove-word) encoded-word)
+        (remhash encoded-word (symbol-value dict))
+        t))
+     (t
+      (message "Cannot remove %S from any active dictionary." word)
+      nil))))
 
 (defun spell-fu-dictionary-add (dict)
   "Add DICT to the list of active dictionaries."
@@ -1304,7 +1306,7 @@ WORD defaults to the word at point if not provided."
     (spell-fu--refresh)))
 
 (defun spell-fu-reset ()
-  "Reset spell-fu and its cache, useful if the cache has somehow become invalid."
+  "Reset spell-fu and it's cache, useful if the cache has somehow become invalid."
   (declare (important-return-value nil))
   (interactive)
   (let ((buffers-in-mode nil))
@@ -1330,7 +1332,7 @@ WORD defaults to the word at point if not provided."
               (buffers-in-mode
                "")
               (t
-               "; no spell-fu buffers found, generate cache on next use!")))))
+               " no buffers in spell-fu found, generate cache on next use!")))))
 
 ;; ---------------------------------------------------------------------------
 ;; Ispell / Aspell dictionary support
@@ -1352,12 +1354,12 @@ Return t if the file was updated."
                dict-file
                (spell-fu--file-is-older
                 words-file
-                ;; Chasing links is needed as checking the symbolic-link date isn't correct, #31.
+                ;; Chase links is needed as checking the symbolic-link date isn't correct, #31.
                 (file-chase-links dict-file))))
          ;; Return value, failure to run `aspell' leaves this nil.
          (updated nil))
 
-    (when (or (null has-words-file) is-dict-outdated)
+    (when (or (not has-words-file) is-dict-outdated)
 
       (spell-fu--with-message-prefix "Spell-fu generating words: "
         (message "%S" (file-name-nondirectory words-file))
@@ -1418,8 +1420,8 @@ Return t if the file was updated."
 
                 (setq word-list (spell-fu--buffer-as-line-list (current-buffer) word-list)))))
 
-          ;; Case insensitive sort is important if this is used for `ispell-complete-word-dict',
-          ;; which is a handy double-use for this file.
+          ;; Case insensitive sort is important if this is used for `ispell-complete-word-dict'.
+          ;; Which is a handy double-use for this file.
           (when updated
             (let ((word-list-ncase nil))
               (dolist (word word-list)
@@ -1429,7 +1431,7 @@ Return t if the file was updated."
               (setq word-list-ncase
                     (sort word-list-ncase (lambda (a b) (string-lessp (car a) (car b)))))
 
-              ;; Needed on Windows to prevent CRLF line endings in strings.
+              ;; Needed for Windows to prevent CRLF including new-lines in strings.
               (let ((coding-system-for-write 'utf-8-unix))
                 ;; Write to 'words-file'.
                 (with-temp-buffer
@@ -1442,14 +1444,14 @@ Return t if the file was updated."
 ;; Word List Initialization
 
 (defun spell-fu--aspell-update (dict dict-name)
-  "Set up the Aspell DICT, named DICT-NAME, initializing it as necessary."
+  "Set up the Aspell DICT, named DICT-NAME initializing it as necessary."
   (declare (important-return-value t))
   ;; Get the paths of temporary files,
   ;; ensure the cache file is newer, otherwise regenerate it.
   (let ((words-file (spell-fu--words-file dict))
         (cache-file (spell-fu--cache-file dict))
         ;; We have to reload the words hash table, if it was not yet loaded.
-        (forced (null (symbol-value dict))))
+        (forced (not (symbol-value dict))))
 
     (when (or (spell-fu--aspell-word-list-ensure words-file dict-name) forced)
       ;; Load cache or create it, creating it returns the cache
@@ -1457,7 +1459,7 @@ Return t if the file was updated."
       (set
        dict
        (or (and (file-exists-p cache-file)
-                (null (spell-fu--file-is-older cache-file words-file))
+                (not (spell-fu--file-is-older cache-file words-file))
                 (spell-fu--cache-words-load cache-file))
            (spell-fu--cache-from-word-list words-file cache-file))))))
 
@@ -1528,7 +1530,7 @@ associated with the dictionary."
 ;;
 
 (defun spell-fu--personal-word-list-ensure (words-file personal-words-file)
-  "Ensure the word list is generated for the personal dictionary.
+  "Ensure the word list is generated for the personal dictionary DICT-NAME.
 Argument WORDS-FILE is the destination file to write the word list into.
 Argument PERSONAL-WORDS-FILE is the source file to read words from.
 
@@ -1539,10 +1541,10 @@ Return t if the file was updated."
          (is-dict-outdated
           (and has-words-file
                has-dict-personal
-               ;; Chasing links is needed as checking the symbolic-link date isn't correct, #31.
+               ;; Chase links is needed as checking the symbolic-link date isn't correct, #31.
                (spell-fu--file-is-older words-file (file-chase-links personal-words-file)))))
 
-    (when (or (null has-words-file) is-dict-outdated)
+    (when (or (not has-words-file) is-dict-outdated)
 
       (spell-fu--with-message-prefix "Spell-fu generating words: "
         (message "%S" (file-name-nondirectory words-file))
@@ -1558,13 +1560,13 @@ Return t if the file was updated."
               (when (looking-at-p "personal_ws-")
                 (delete-region (pos-bol) (1+ (pos-eol))))
               (goto-char (point-max))
-              (unless (eq ?\n (char-before))
+              (unless (eq ?\n (char-after))
                 (insert "\n")))
 
             (setq word-list (spell-fu--buffer-as-line-list (current-buffer) word-list)))
 
-          ;; Case insensitive sort is important if this is used for `ispell-complete-word-dict',
-          ;; which is a handy double-use for this file.
+          ;; Case insensitive sort is important if this is used for `ispell-complete-word-dict'.
+          ;; Which is a handy double-use for this file.
           (let ((word-list-ncase nil))
             (dolist (word word-list)
               (push (cons (downcase word) word) word-list-ncase))
@@ -1589,7 +1591,7 @@ Argument DICT-FILE is the absolute path to the dictionary."
   (let ((words-file (spell-fu--words-file dict))
         (cache-file (spell-fu--cache-file dict))
         ;; We have to reload the words hash table, if it was not yet loaded.
-        (forced (null (symbol-value dict))))
+        (forced (not (symbol-value dict))))
 
     (when (or (spell-fu--personal-word-list-ensure words-file dict-file) forced)
       ;; Load cache or create it, creating it returns the cache
@@ -1597,7 +1599,7 @@ Argument DICT-FILE is the absolute path to the dictionary."
       (set
        dict
        (or (and (file-exists-p cache-file)
-                (null (spell-fu--file-is-older cache-file words-file))
+                (not (spell-fu--file-is-older cache-file words-file))
                 (spell-fu--cache-words-load cache-file))
            (spell-fu--cache-from-word-list words-file cache-file))))))
 
@@ -1617,13 +1619,14 @@ Argument DICT-FILE is the absolute path to the dictionary."
         (insert-file-contents-literally dict-file)
 
         ;; Ensure newline at EOF,
-        ;; not essential but complicates sorted adding if we don't do this.
+        ;; not essential but complicates sorted add if we don't do this.
         ;; also ensures we can step past the header which _could_ be a single line
         ;; without anything below it.
         (goto-char (point-max))
         (unless (string-blank-p (buffer-substring-no-properties (pos-bol) (pos-eol)))
           (insert "\n"))
-        ;; Delete extra blank lines so we can use line count as word count.
+        ;; Delete extra blank lines.
+        ;; So we can use line count as word count.
         (while (and (zerop (forward-line -1))
                     (string-blank-p (buffer-substring-no-properties (pos-bol) (pos-eol))))
           (delete-region
@@ -1660,6 +1663,7 @@ Argument DICT-FILE is the absolute path to the dictionary."
               (message "\"%s\" already in the personal dictionary." word)
               (throw 'result nil))
 
+
             (let ((keep-searching t))
               (while (and keep-searching
                           (string-lessp (buffer-substring-no-properties (pos-bol) (pos-eol)) word))
@@ -1751,7 +1755,7 @@ Argument DICT-FILE is the absolute path to the dictionary."
     (setq spell-fu--buffer-localwords-cache-table word-table)))
 
 (defun spell-fu--buffer-localwords-add-or-remove (word action)
-  "Add or remove WORD from buffer-local words depending on ACTION."
+  "Add or remove WORD from buffer local names depending on ACTION."
   (declare (important-return-value t))
   (catch 'result
     (spell-fu--with-message-prefix "Spell-fu: "
@@ -1776,7 +1780,7 @@ Argument DICT-FILE is the absolute path to the dictionary."
 
            ((eq action 'remove)
             (unless word-in-dict
-              (message "\"%s\" not in the local dictionary." word)
+              (message "\"%s\" not in the personal dictionary." word)
               (throw 'result nil))
 
             (setq spell-fu-buffer-session-localwords
@@ -1794,13 +1798,14 @@ Argument DICT-FILE is the absolute path to the dictionary."
             t))))))
 
 (defun spell-fu-get-buffer-session-localwords-dictionary ()
-  "Get the buffer-local session words dictionary."
+  "Get the personal dictionary NAME.
+Argument DICT-FILE is the absolute path to the dictionary."
   (declare (important-return-value t))
   (let ((dict 'spell-fu--buffer-localwords-cache-table))
     ;; Start with no words - construct them lazily
     (set dict nil)
     ;; Set description
-    (put dict 'description "Buffer-local dictionary")
+    (put dict 'description "Buffer local dictionary")
     ;; Set update function
     (put dict 'update #'spell-fu--buffer-localwords-cache-table-update)
     ;; Set add/remove functions
@@ -1920,17 +1925,17 @@ Argument DICT-FILE is the absolute path to the dictionary."
          ;; Not already enabled.
          (not spell-fu-mode)
          ;; Not in the mini-buffer.
-         (null (minibufferp))
-         ;; Not a special mode (package list, tabulated data, etc.)
+         (not (minibufferp))
+         ;; Not a special mode (package list, tabulated data ... etc)
          ;; Instead the buffer is likely derived from `text-mode' or `prog-mode'.
-         (null (derived-mode-p 'special-mode))
+         (not (derived-mode-p 'special-mode))
          ;; Not explicitly ignored.
-         (null (memq major-mode spell-fu-ignore-modes))
+         (not (memq major-mode spell-fu-ignore-modes))
          ;; Optionally check if a function is used.
          (or (null spell-fu-global-ignore-buffer)
              (cond
               ((functionp spell-fu-global-ignore-buffer)
-               (null (funcall spell-fu-global-ignore-buffer (current-buffer))))
+               (not (funcall spell-fu-global-ignore-buffer (current-buffer))))
               (t
                nil))))
     (spell-fu-mode 1)))
